@@ -1,5 +1,5 @@
 #
-# $Id: Layer.pm 2003 2012-09-02 16:43:45Z gomor $
+# $Id: Layer.pm 2005 2015-01-23 06:56:13Z gomor $
 #
 package Net::Write::Layer;
 use strict;
@@ -81,18 +81,24 @@ sub _setIpHdrInclConstant {
    eval "use constant NW_IP_HDRINCL => $val;";
 }
 
-sub _setAfinet6Constant {
-   require Socket6;
-   require Socket;
-   my $val = 0;
-   if (defined(&Socket6::AF_INET6)) {
-      $val = &Socket6::AF_INET6;
-   }
-   elsif (defined(&Socket::AF_INET6)) {
-      $val = &Socket::AF_INET6;
-   }
-   eval "use constant NW_AF_INET6  => $val;";
-}
+#
+# ACF - This could result in NW_AF_INET6 => 0 if neither
+# Socket6::AF_INET6 nor Socket::AF_INET6 is defined.  My change
+# doesn't preserve that, but it isn't clear that was an intended or
+# useful feature.
+#
+#sub _setAfinet6Constant {
+#   require Socket6;
+#   require Socket;
+#   my $val = 0;
+#   if (defined(&Socket6::AF_INET6)) {
+#      $val = &Socket6::AF_INET6;
+#   }
+#   elsif (defined(&Socket::AF_INET6)) {
+#      $val = &Socket::AF_INET6;
+#   }
+#   eval "use constant NW_AF_INET6  => $val;";
+#}
 
 BEGIN {
    my $osname = {
@@ -100,22 +106,48 @@ BEGIN {
       MSWin32 => \&_checkWin32,
    };
 
-   *_check  = $osname->{$^O} || \&_checkOther;
+   {
+     no strict 'refs';
+     *{ __PACKAGE__ . "::_check" } = $osname->{$^O} || \&_checkOther;
+   }
    _setIpProtoIpConstant();
    _setIpProtoIpv6Constant();
    _setIpProtoRawConstant();
    _setIpHdrInclConstant();
-   _setAfinet6Constant();
+   #_setAfinet6Constant();
+}
+
+use Socket qw(:DEFAULT AF_INET);
+BEGIN {
+    # imports that may or may not be in Socket.
+    my @imports = (qw(AF_INET6 getaddrinfo));
+    my @socket6_imports;
+
+    # This might be overkill, but I'm not certain that all these imports
+    # were added to Socket at the same time.
+    for my $import (@imports) {
+        eval { Socket->import($import); };
+        if ($@) {
+            push @socket6_imports, $import;
+        }
+    }
+
+    if (@socket6_imports) {
+
+        # something we want wasn't found in Socket time to try Socket6
+        eval { require Socket6 };
+        die $@ if $@;
+        Socket6->import(@socket6_imports);
+    }
 }
 
 no strict 'vars';
 
-use Socket;
-use Socket6 qw(getaddrinfo);
 use IO::Socket;
 use Net::Pcap;
 
 use constant NW_AF_INET   => AF_INET();
+use constant NW_AF_INET6  => AF_INET6();
 use constant NW_AF_UNSPEC => AF_UNSPEC();
 
 use constant NW_IPPROTO_ICMPv4 => 1;
@@ -336,7 +368,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2012, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
